| Title: | Cystic Fibrosis Survival Prediction Model Based on Stanojevic Model |
|---|---|
| Description: | Allows clinicians to predict survival probabilities over the next two years for cystic fibrosis patients, based on the clinical prediction models published in Stanojevic et al. (2019) <doi:10.1183/13993003.00224-2019>. |
| Authors: | Sanja Stanojevic [aut, cph], Jenna Sykes [aut, cph], George A. Whitmore [aut, cph], Shawn D. Aaron [aut, cph], Aida Kazemi [aut], Amin Adibi [aut, cre] |
| Maintainer: | Amin Adibi <[email protected]> |
| License: | GPL-3 |
| Version: | 0.3.0 |
| Built: | 2026-05-15 07:22:30 UTC |
| Source: | https://github.com/cran/cfmortality |
Predicts 1- and 2- year Mortality Prediction Models in Cystic Fibrosis (CF)
predictcfmortality( age, male, fvc, fev1, fev1LastYear, bcepacia, underweight, nHosp, pancreaticInsufficient, CFRelatedDiabetes, ageAtDiagnosis )predictcfmortality( age, male, fvc, fev1, fev1LastYear, bcepacia, underweight, nHosp, pancreaticInsufficient, CFRelatedDiabetes, ageAtDiagnosis )
age |
Patient age, in years |
male |
A binary variable with 0 for females and 1 for males |
fvc |
FVC percent predicted in the current year (0-150) |
fev1 |
FEV1 percent predicted in the current year (0-150) |
fev1LastYear |
FEV1 percent predicted in the preceding year (0-150) |
bcepacia |
A binary with 0 for no B. cepacia complex and 1 for B. cepacia complex |
underweight |
A binary with 1 for underweight (BMI < 18.5 if age >= 19 or BMI percentile <= 12% if age < 19) |
nHosp |
An integer number of hospitalizations in preceding year |
pancreaticInsufficient |
A binary taking 1 for pancreatic insufficient status and 0 otherwise |
CFRelatedDiabetes |
A binary variable for CF related diabetes |
ageAtDiagnosis |
A number for age at CF diagnosis in years |
1- and 2-year predicted mortality risk
https://erj.ersjournals.com/content/early/2019/05/08/13993003.00224-2019
predictcfmortality (age = 16, male = 0, fvc = 66.7, fev1 = 47.4, fev1LastYear = 80.5, bcepacia = 0, underweight = 0, nHosp = 0, pancreaticInsufficient = 1, CFRelatedDiabetes = 0, ageAtDiagnosis = 0.9) predictcfmortality (age = 40.4, male = 1, fvc = 25.7, fev1 = 19.2, fev1LastYear = 20, bcepacia = 1, underweight = 1, nHosp = 6, pancreaticInsufficient = 0, CFRelatedDiabetes = 0, ageAtDiagnosis = 27.2) predictcfmortality (age = 44, male = 1, fvc = 72.95, fev1 = 55.5, fev1LastYear = 52.5, bcepacia = 0, underweight = 1, nHosp = 0, pancreaticInsufficient = 0, CFRelatedDiabetes = 0, ageAtDiagnosis = 29)predictcfmortality (age = 16, male = 0, fvc = 66.7, fev1 = 47.4, fev1LastYear = 80.5, bcepacia = 0, underweight = 0, nHosp = 0, pancreaticInsufficient = 1, CFRelatedDiabetes = 0, ageAtDiagnosis = 0.9) predictcfmortality (age = 40.4, male = 1, fvc = 25.7, fev1 = 19.2, fev1LastYear = 20, bcepacia = 1, underweight = 1, nHosp = 6, pancreaticInsufficient = 0, CFRelatedDiabetes = 0, ageAtDiagnosis = 27.2) predictcfmortality (age = 44, male = 1, fvc = 72.95, fev1 = 55.5, fev1LastYear = 52.5, bcepacia = 0, underweight = 1, nHosp = 0, pancreaticInsufficient = 0, CFRelatedDiabetes = 0, ageAtDiagnosis = 29)